@@ -57,6 +57,7 @@ def issues_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
         link = nodes.reference(rawtext, '#' + issue_no, refuri=ref, **options)
     else:
         link = None
+        issue_no = None # So it doesn't gum up dupe detection later
     # Additional 'new-style changelog' stuff
     if name in issue_types:
         nodelist = issue_nodelist(name, link)
@@ -165,6 +166,9 @@ def construct_releases(entries, app):
     # per-release buckets as releases are encountered. Store releases in order.
     releases = []
     lines = {'unreleased_bugfix': [], 'unreleased_minor': []}
+    # Also keep a master hash of issues by number to detect duplicates & assist
+    # in explicitly defined release lists.
+    issues = {}
     for obj in reversed(entries):
         # The 'actual' intermediate object we want to focus on is wrapped first
         # in a LI, then a P.
@@ -172,45 +176,92 @@ def construct_releases(entries, app):
         log(repr(focus))
         # Releases 'eat' the entries in their line's list and get added to the
         # final data structure. They also inform new release-line 'buffers'.
-        # Release lines should have an empty 'rest' so it's ignored.
+        # Release lines' "rest" should be empty or a comma-separated list of
+        # issue numbers.
         if isinstance(focus, release):
             line = get_line(focus)
             log("release for line %r" % line)
-            # New release line/branch detected. Create it & dump unreleased
-            # features.
-            if line not in lines:
-                log("not seen prior, making feature release")
-                lines[line] = []
-                entries = [
-                    x
-                    for x in lines['unreleased_minor']
-                    if x.type in ('feature', 'support') or x.major
-                ]
-                log("entries in this release: %r" % (entries,))
-                releases.append({
-                    'obj': focus,
-                    'entries': entries
-                })
-                lines['unreleased_minor'] = []
-            # Existing line -> empty out its bucket into new release.
-            # Skip 'major' bugs as those "belong" to the next release (and will
-            # also be in 'unreleased_minor' - so safe to nuke the entire
-            # line)
-            else:
-                log("pre-existing, making bugfix release")
-                entries = [x for x in lines[line] if not x.major]
+            # Check for explicitly listed issues first
+            explicit = None
+            if rest:
+                explicit = [x.strip() for x in rest[0].split(',')]
+            # Do those by themselves since they override all other logic
+            if explicit:
+                log("Explicit issues requested: %r" % (explicit,))
+                # First scan global issue dict, dying if not found
+                missing = [i for i in explicit if i not in issues]
+                if missing:
+                    raise ValueError("Couldn't find issue(s) #%s in the changelog!" % (', '.join(missing)))
+                # Obtain objects from global list
+                entries = [issues[i] for i in explicit]
+                # Create release
                 log("entries in this release: %r" % (entries,))
                 releases.append({
                     'obj': focus,
                     'entries': entries,
                 })
-                lines[line] = []
-                # Clean out the items we just released from
-                # 'unreleased_bugfix'.  (Can't nuke it because there might be
-                # some unreleased bugs for other release lines.)
-                for x in entries:
-                    if x in lines['unreleased_bugfix']:
-                        lines['unreleased_bugfix'].remove(x)
+                # Introspect entries to determine which buckets they should get
+                # removed from
+                for obj in entries:
+                    if obj.type == 'bug':
+                        # Major bugfix: remove from unreleased_minor
+                        if obj.major:
+                            log("Removing #%s from unreleased" % obj.number)
+                            lines['unreleased_minor'].remove(obj)
+                        # Regular bugfix: remove from bucket for this release's
+                        # line + unreleased_bugfix
+                        else:
+                            if obj in lines['unreleased_bugfix']:
+                                log("Removing #%s from unreleased" % obj.number)
+                                lines['unreleased_bugfix'].remove(obj)
+                            if obj in lines[line]:
+                                log("Removing #%s from %s" % (obj.number, line))
+                                lines[line].remove(obj)
+                    # Regular feature/support: remove from unreleased_minor
+                    # Backported feature/support: remove from bucket for this
+                    # release's line (if applicable) + unreleased_minor
+                    else:
+                        log("Removing #%s from unreleased" % obj.number)
+                        lines['unreleased_minor'].remove(obj)
+                        if obj in lines.get(line, []):
+                            lines[line].remove(obj)
+
+            # Implicit behavior otherwise
+            else:
+                # New release line/branch detected. Create it & dump unreleased
+                # features.
+                if line not in lines:
+                    log("not seen prior, making feature release")
+                    lines[line] = []
+                    entries = [
+                        x
+                        for x in lines['unreleased_minor']
+                        if x.type in ('feature', 'support') or x.major
+                    ]
+                    releases.append({
+                        'obj': focus,
+                        'entries': entries
+                    })
+                    lines['unreleased_minor'] = []
+                # Existing line -> empty out its bucket into new release.
+                # Skip 'major' bugs as those "belong" to the next release (and will
+                # also be in 'unreleased_minor' - so safe to nuke the entire
+                # line)
+                else:
+                    log("pre-existing, making bugfix release")
+                    entries = [x for x in lines[line] if not x.major]
+                    log("entries in this release: %r" % (entries,))
+                    releases.append({
+                        'obj': focus,
+                        'entries': entries,
+                    })
+                    lines[line] = []
+                    # Clean out the items we just released from
+                    # 'unreleased_bugfix'.  (Can't nuke it because there might be
+                    # some unreleased bugs for other release lines.)
+                    for x in entries:
+                        if x in lines['unreleased_bugfix']:
+                            lines['unreleased_bugfix'].remove(x)
         # Entries get copied into release line buckets as follows:
         # * Features and support go into 'unreleased_minor' for use in new
         # feature releases.
@@ -237,6 +288,11 @@ def construct_releases(entries, app):
                 )
             else:
                 focus.attributes['description'] = rest
+            # Add to global list or die trying
+            if focus.number and focus.number in issues:
+                raise ValueError("You seem to have defined issue #%s twice! Please double check." % focus.number)
+            else:
+                issues[focus.number] = focus
             if focus.type == 'bug':
                 # Major bugs go into unreleased_minor
                 if focus.major:
